Tutorials
=========

Here are some simple tutorials, showing how :py:mod:`kinisi` may be used to analysis a VASP Xdatcar file, an :py:class:`MDAnalysis.core.universe.Universe` object, and how it is possible to leverage :py:mod:`kinisi` to distinguish between Arrhenius and super-Arrhenius behaviour. 

.. toctree::
   :maxdepth: 1

   vasp 
   mdanalysis
   arrhenius_vs_super